@@ -195,6 +195,31 @@
 #'     xlab("Per 100 Words") + 
 #'     scale_y_continuous(labels = percent) +
 #'     ggthemes::theme_few()
+#'     
+#' ## Discourse Markers: See...
+#' ## Schffrin, D. (2001). Discourse markers: Language, meaning, and context. 
+#' ##    In D. Schiffrin, D. Tannen, & H. E. Hamilton (Eds.), The handbook of 
+#' ##    discourse analysis (pp. 54-75). Malden, MA: Blackwell Publishing.
+#' 
+#' discoure_markers <- list(
+#'     response_cries = c(" oh ", " ah ", " aha ", " ouch ", " yuk "),
+#'     back_channels = c(" uh-huh ", " uhuh ", " yeah "), 
+#'     summons = " hey ", 
+#'     justification = " because "
+#' )
+#' 
+#' (markers <- with(pres_debates2012, 
+#'     termco(dialogue, list(person, time), discoure_markers)
+#' ))
+#' plot(markers, high="red")
+#' 
+#' with(pres_debates2012, 
+#'     termco(dialogue, list(person, time), discoure_markers, elim.old = FALSE)
+#' )
+#' 
+#' with(pres_debates2012, 
+#'     dispersion_plot(dialogue, unlist(discoure_markers), person, time)
+#' )
 #' }
 termco <-
 function (text.var, grouping.var = NULL, match.list, short.term = TRUE,
@@ -350,7 +375,12 @@ function (text.var, grouping.var = NULL, match.list, short.term = TRUE,
     if (short.term) {
         o <- termco2short.term(o)
     }
+
     class(o) <- "termco"
+    if (!is.null(attributes(TD[["raw"]])[["by.row"]])) {
+        attributes(o[["raw"]])[["by.row"]] <- attributes(TD[["raw"]])[["by.row"]]
+        colnames(attributes(o[["raw"]])[["by.row"]])[1] <- colnames(o[["raw"]])[1]
+    }
     o
 }
 
@@ -413,12 +443,14 @@ termco_d <-
     if (short.term) {
         o <- termco2short.term(o)
     }
+    if (!is.null(attributes(o[["raw"]])[["by.row"]])) {
+        colnames(attributes(o[["raw"]])[["by.row"]])[1] <- colnames(o[["raw"]])[1]
+    }      
     class(o) <- "termco"    
     o 
 }
 
 
-
 #' Search a Transcript for Terms
 #' 
 #' \code{term_match} - Search a transcript for words that exactly match term(s).
